##Component Overview

###Modes
* **Polling:** Basic operation initialization without support of interrupts and transactional API.
* **Interrupt:** Polling mode is extended by initialization of the interrupts. The interrupt routines are defined by users.
* **Transfer:** Polling mode is extended by initialization of transfer mode. This mode supports transactional APIs.

### Polling Mode
This is general initialization of the FlexIO peripheral in the I²C master mode. This part of the initialization is used in other modes as well.  
  
__Clock source and clock source frequency:__ *Choosing clock source and clock source frequency which is used for FlexIO*  
  
The configuration of the I²C is separated into two parts: configuration of the FlexIO peripheral, and Master I²C configuration which configures the I²C protocol.
  
__FlexIO peripheral configuration__  
  - __SDA and SCL pins:__ *Choose the pin to use for each signal*
  - __Shifters for transmitting and receiving data:__ *Set the indexes of the shifters. Index of the shifter has to be unique.*

  - __Timers for baudrate, clock edges shift and controlling the data shifters:__ *Index of the timer. Index of the timer has to be unique.*
  
__Master I2C configuration__  
  - __Enable device in initialization, doze mode and debug mode__
  - __Enable fast access to FlexIO registers__
  - __Requested and calculated baud rate [bps]:__ *If the requested baud rate is set, the calculated baud rate displays the baud rate which is used for real communication*.
  
### Interrupt Mode  
This initialization is available if the interrupt mode is set. It's possible to choose interrupt sources, set the handler function name and the priority of the interrupt.  

__Interrupt configuration__
  - __Interrupt sources__
    - __Empty Tx buffer:__ *Invokes if the Tx data buffer is empty.*  
    - __Full Rx buffer:__ *Invokes if the Rx data buffer is full.*  
  
[More information about the interrupt configuration is available here.](system::interrupt.md)  
  
### Transfer Mode  
This initialization is available if the transfer mode is set. A transfer handle is created and you can select the callback function, user data pointer and create a data buffer.  

__Transfer configuration__
  - __Transfer handle ID:__ *The transfer handle ID is used in the runtime functions in the transfer API.*
  - __Create buffer variable:__ *The buffer variable can be used by the user in runtime functions.*
  - __Buffer__
    - __Name:__ *The ID of the buffer is used in runtime functions and the transfer structure.*
    - __Size [byte]:__ *Set the buffer size.*
  - __Transfer callback initialization:__ *Set if the callback function name is available.*
  - __Transfer callback function name:__ *Set the name of the function.*
  - __User data pointer:__ *Set the name of the user data pointer.*

### Pins Dependencies
The component instance reports pins (SDA and SCL pins) which are not routed in the Pins tool configuration. You can resolve the warning by configuring the pins in the Pins tool. Alternatively, a quick fix is available by right-clicking the warning in the Problems view