##Polling Mode

The polling mode uses a basic function for handling the I2C communication.  
This example of master mode demonstrates writing data to or reading data from the slave device.
The slave mode is not available for the FlexIO peripheral, but is available to other peripherals, such as I2C, LPI2C etc.  


**1. Configure the component as follows:**  
- **Mode:** `Polling`  


- Set general component configuration (see Use cases page)  


**2. Copy the following code into your section of the definitions:**

---

`#define FLEXIO3_BUFFER_SIZE 10U /* Buffer size */`


---

**3. Copy the following code into your declaration of the variables:**

---

    flexio_i2c_master_transfer_t masterXfer; /* FlexIO I2C master structure */
    status_t masterTransferStatus; /* Status of the transfer */
    uint8_t FLEXIO3_buffer[FLEXIO3_BUFFER_SIZE]; /* Data buffer */


---

**4. Copy the following code into your application main code:**

>a. Fulfill data buffer in case of the writing the data  

---

>
    /* Example of the data 
    FLEXIO3_buffer[0] = FLEXIO3_BUFFER_SIZE - 1U;
    for (uint32_t i = 1U; i < FLEXIO3_BUFFER_SIZE; i++)
    {
        FLEXIO3_buffer[i] = i - 1;
    }

---

>b. Set Master transfer structure

---

>
    memset(&masterXfer, 0, sizeof(masterXfer));
    /* Master transfer structure*/
    masterXfer.slaveAddress   = 0x7EU; /* Slave address*/
    masterXfer.subaddress     = 0;
    masterXfer.subaddressSize = 0;
    masterXfer.data           = FLEXIO3_buffer; /* Data buffer*/
    masterXfer.dataSize       = FLEXIO3_BUFFER_SIZE; /* Data buffer size*/
    masterXfer.flags = 0; /* Status flags*/  

---

>c. Set data transfer direction (choose one item below)  
  
>Write data  

---

>`masterXfer.direction      = kFLEXIO_I2C_Write; /* Transfer direction - write*/`  

---

>Or read data  

---

>`masterXfer.direction      = kFLEXIO_I2C_Read; /* Transfer direction - read*/`  

---

>d. Call initialization of the FlexIO peripheral  

---

>`BOARD_InitBootPeripherals();`

---

>e. Call transfer function  

---

>`masterTransferStatus = FLEXIO_I2C_MasterTransferBlocking(&FLEXIO3_peripheralConfig, &masterXfer);`  

---

Note: This example is relevant for the FLEXIO3 peripheral instance and must be modified for use with a different peripheral instance.

**5. Run the application**
