##Transfer Mode

This is the example of the I²C communication using the `FLEXIO_I2C_MasterTransferNonBlocking` function and FlexIO I2C master handle structure. 
This example of master mode demonstrates writing data to or reading data from the slave device.
The slave mode is not available for the FlexIO peripheral, but it is available for other peripherals, such as I2C, LPI2C etc.  

**1. Configure component as follows:**  
- **Mode:** `Transfer`  


- Set general component configuration (see Use cases page)  


- **Transfer configuration**
    - **Transfer handle ID:** `FLEXIO3_handle`
    - **Create buffer variable:** ☑
    - **Buffer**
        - **Name:** `FLEXIO3_buffer`
        - **Size [byte]:** `10`
    - **Transfer callback initialization:** ☑
    - **Transfer callback function name:** `FLEXIO_I2C_Master_callback`
  
Note: __Transfer handle ID__ and __Buffer name__ can be different depending on FlexIO instance name. These settings are intended for the FLEXIO3 peripheral.


**2. Copy the following code into your declaration of the variables:**

---

    volatile bool completionFlag = false; /* Transfer completion flag */
    volatile bool nakFlag        = false; /* Transfer NAK flag, signal transfer unsuccess */
    flexio_i2c_master_transfer_t masterXfer; /* FlexIO I2C master transfer structure */
    IRQn_Type flexio_irqs[] = FLEXIO_IRQS; /* FlexIO IRQs array */
    status_t masterTransferStatus; /* Status of the transfer */

---

**3. Copy following code into your declaration of the functions:**

---

    void FLEXIO_I2C_Master_callback(FLEXIO_I2C_Type *base, flexio_i2c_master_handle_t *handle, status_t status, void *userData)
    {
        /* Signal transfer success when received success status. */
        if (status == kStatus_Success)
        {
            completionFlag = true;
        }
        /* Signal transfer unsuccess when received NAK status. */
        if (status == kStatus_FLEXIO_I2C_Nak)
        {
            nakFlag = true;
        }
    }

---


**4. Copy the following code into your application main code:**

>a. Set interrupt priority of FlexIO peripheral  

---

>`NVIC_SetPriority(flexio_irqs[FLEXIO_GetInstance(FLEXIO3_PERIPHERAL)], 1);`  

---

>b. Fulfill data buffer in case of the writing the data  

---

>
    /* Example of the data 
    FLEXIO3_buffer[0] = FLEXIO3_BUFFER_SIZE - 1U;
    for (uint32_t i = 1U; i < FLEXIO3_BUFFER_SIZE; i++)
    {
        FLEXIO3_buffer[i] = i - 1;
    }

---

>c. Set Master transfer structure

---

>
    memset(&masterXfer, 0, sizeof(masterXfer));
    /* Master transfer structure*/
    masterXfer.slaveAddress   = 0x7EU; /* Slave address*/
    masterXfer.subaddress     = 0;
    masterXfer.subaddressSize = 0;
    masterXfer.data           = FLEXIO3_buffer; /* Data buffer*/
    masterXfer.dataSize       = FLEXIO3_BUFFER_SIZE; /* Data buffer size*/
    masterXfer.flags = 0; /* Status flags*/  

---

>d. Set data transfer direction (choose one item below)  
  
>Write data  

---

>`masterXfer.direction      = kFLEXIO_I2C_Write; /* Transfer direction - write*/`  

---

>Or read data  

---

>`masterXfer.direction      = kFLEXIO_I2C_Read; /* Transfer direction - read*/`  

---

>e. Initialize items of the transfer handle(FLEXIO3_handle) to 0  

---

>`memset(&FLEXIO3_handle, 0, sizeof(FLEXIO3_handle));`

---

>f. Call initialization of the FlexIO peripheral  

---

>`BOARD_InitBootPeripherals();`

---

>g. Call transfer function  


---

>`masterTransferStatus = FLEXIO_I2C_MasterTransferNonBlocking(&FLEXIO3_peripheralConfig, &FLEXIO3_handle, &masterXfer);`  

---

Note: This example is relevant for the FLEXIO3 peripheral instance and must be modified for use with a different peripheral instance.

**5. Run the application**