##Peripheral Overview

The FlexIO is a highly configurable module providing a wide range of functionality
including:
- Emulation of a variety of serial/parallel communication protocols
- Flexible 16-bit timers with support for a variety of trigger, reset, enable and disable
conditions

![FlexIO block diagram](img/FlexIO_block_diagram.png)

**Figure 1.** *FlexIO block diagram*

##I²C Master Mode

I²C bus is typically used for attaching lower-speed peripheral ICs to processors and microcontrollers in short-distance, intra-board communication.  

![i2c](img/i2c_scheme.png)

**Figure 2.** *I²C bus scheme*


  * The I²C bus uses 2 main signal lines SCL (Serial clock line) and SDA (Serial data line)
  * The master is initially in master transmit mode by sending a START followed by the 7-bit 
  address of the slave it wishes to communicate with, which is finally followed by a single bit 
  representing whether it wishes to write (0) to or read (1) from the slave.
  * If the slave exists on the bus then it will respond with an ACK bit (active low for acknowledged)
  for that address. 
  * The master then continues in either transmit or receive mode (according to the read/write 
  bit it sent), and the slave continues in the complementary mode (receive or transmit, respectively).
  * The most significant bit from (address or data) byte is sent first.
  * The START bit is indicated by a high-to-low transition of SDA (1➡0) with SCL high (1).
  * The STOP bit is indicated by a low-to-high transition of SDA (0➡1) with SCL high (1). 
  * All other transitions of SDA take place with SCL low (0).
  * If the master wishes to **write** to the slave, then it repeatedly sends a byte with the slave sending
  an ACK bit. (In this situation, the master is in master transmit mode, and the slave is in slave receive mode.)
  * If the master wishes to **read** from the slave, then it repeatedly receives a byte from the slave, the master
  sending an ACK bit after every byte except the last one. (In this situation, the master is in master receive mode,
  and the slave is in slave transmit mode.)
  * An I²C transaction may consist of multiple messages.
  * The master terminates a message with a STOP condition if this is the end of the transaction or it may send another
  START condition to retain control of the bus for another message (a "combined format" transaction).
  
I²C master mode is supported using two Timers, two Shifters and two Pins of the FlexIO peripheral. One timer
 is used to generate the SCL output and one timer is used to control the shifters. The two shifters
 are used to transmit and receive for every word, when receiving the transmitter must transmit 0xFF to tristate the output.
 FlexIO inserts a stop bit after every word to generate/verify the ACK/NACK. FlexIO waits for the first write to the transmit
 data buffer before enabling SCL generation. I²C Slave mode is not supported.

The maximum baud rate is equal to the FlexIO clock frequency divided by 6.
    
For more information visit [NXP I²C bus user manual](http://www.nxp.com/documents/user_manual/UM10204.pdf).

![i2c_com](img/i2c_signal.png)

**Figure 3.** *I²C main signal lines*