##Peripheral Overview

Flexible Serial Peripheral Interface (FlexSPI) host controller supports two SPI channels and up to 4 external devices. 


FlexSPI block supports the following features:
- Flexible sequence engine (LUT table) to support various vendor devices
    - Serial NOR Flash or other device with similar SPI protocol as Serial NOR Flash
- Flash access mode
    - Single/Dual/Quad/Octal mode
    - SDR/DDR mode
    - Individual mode
- Support sampling clock mode
    - Internal dummy read strobe loopbacked internally
    - Internal dummy read strobe loopbacked from pad
    - Flash provided read strobe
- Memory mapped read/write access by AHB Bus
    - AHB RX Buffer implemented to reduce read latency. Total AHB RX Buffer size: 128 * 64 Bits
    - 16 AHB masters supported with priority for read access
    - AHB TX Buffer implemented to buffer all write data from one AHB burst. AHB TX Buffer size: 8 * 64 Bits
    - All AHB masters share this AHB TX Buffer. No AHB master number limitation for Write Access
- Software triggered Flash read/write access by IP Bus
    - IP RX FIFO implemented to buffer all read data from External device. FIFO size: 16 * 64 Bits
    - IP TX FIFO implemented to buffer all Write data to External device. FIFO size: 16 * 64 Bits
    - DMA support to fill IP TX FIFO
    - DMA support to read IP RX FIFO
    - SCLK stopped when reading flash data and IP RX FIFO is full
    - SCLK stopped when writing flash data and IP TX FIFO is empty

### Flash Connection

There are two FlexSPI interface ports (A port and B port). Each port supports 2 flash devices by providing 2 chip select outputs.
FlexSPI configuration is dependent on the chip configuration.

![pic](flash_connection.png)  

**Figure 1.** *Flash connection diagram with four devices*

- Flash A1 and A2 could be two flash chip package or two flash die on the same package. There is no difference to FlexSPI.
Same for Flash B1 and B2.
- For now, is available only individual mode. A1, A2, B1 and B2 could not be accessed at the same time. 
But these four device could be accessed separately.

### Look Up Table

The LUT (Look Up Table) is an internal memory to preserve a number of preprogrammed sequences. 
Each sequence consists of up to 8 instructions which are executed sequentially.When a flash access is triggered by an IP command or an AHB command, 
FlexSPI controller will fetch the sequence from LUT according to sequenceindex/number and execute it to generate a valid flash transaction on SPI interface.

![pic](lut.png)  

**Figure 2.** *LUT and sequence structure*

To customize the LUT sequence for some specific device, users need to enable "lutCustomSeqEnable" and fill in corresponding "lutCustomSeq" field specified by
command index below.

For Serial (SPI) NOR, the pre-defined LUT index is as follows:

![pic](lut1.png)  
![pic](lut2.png)  

**Figure 3.** *LUT sequence definition for Serial NOR*

