##Component Overview

The picture below displays high level blocks of one HW submodule (SM) with highlighted relation between the component settings and the HW submodule:

 ![pwm_submodule_scheme](pwm_high_level_diagram.PNG)  
  **Figure 6.** *Interconnection between HW parts and the component*

### Blocks of the PWM Signal Generation from Fig.6  

    Flow of the PWM signals through blocks:
*   Clock source - Clocks the counter after division by selected **Counter prescaler** item.
*   Counter (PWM Generation block) - Compare values that generate raw PWM outputs, which go to the Force out logic.
*   Force out logic block - Selects signals which go to the Deadtime insertion block. Synchronization trigger for switching the signal source is specified in the **FORCE_OUT trigger** item in Main configuration section of SM. Available Force out signals sources (**SMx => Channels => PWM =>  Deadtime logic input** item) are:
    * Raw PWM signal
    * Inverted raw PWM signal
    * SW driven logical value SWCOUT[SMxOUT23]/SWCOUT[SMxOUT45] for PWMA/PWMB
    * EXTA/EXTB signal - Signal external to the PWM module (PWM_EXTA/EXTB for PWMA/PWMB) - specified by the routing in the Pins tool.
*   Deadtime insertion block - Adds deadtime to the raw PWM outputs (or to the others output signals of the Force out logic block) to create real PWM output.
*   Fault protection block - Gates PWM output and when there is not fault state on the fault inputs related to this PWM signal, which goes to the output logic block.
*   Output logic block - Final part of the PWM generation goes to the output pins (outputs can be disabled/masked or replaced by the safe fault state).

### Clock Sources

* Bus clock - Source for the deadtime and fault input filter and also can be used as the counter clock.
* AUX clock - Clock from the SM0 after its divider, for synchronization of the SMs.
* EXT_CLK - Source external to the PWM module and can be routed in the Pins tool.

### Submodule Settings

*   Main configuration - Related to the clocking and the counter settings as a whole.
    *   Counter settings (Each SM has its own counter and compare values 0-5):
        * Compare value 1 is taken as a modulo - Calculated by SDK driver from Desired counter frequency/period item in Main configuration of SM
        * Compare value 0 is taken as half of the period - Given by driver, HW allows to specify the compare independently. Its output is used as PWM channel X output, but now it is not possible to use it (driver limitation).

        * Compare values 2 and 3 create PWM output for channel A calculated by SDK driver from Pulse width item.
        * Compare values 4 and 5 create PWM output for channel B calculated by SDK driver from Pulse width item.

*   Channels:
    *   A and B are channels available to generate the PWM outputs with deadtime in the output form / can be used as the Capture inputs.
    *   X can be used as the Capture input only (limitation of the driver: compare value 0 is set to be the middle of the period)
    *   Channel settings

        * Options of channel modes: Not used, PWM (output) or capture (input)
        * In case of complementary PWM output of the channels A and B the deadtime can be specified
        * Deadtime logic input item (force out logic output) is available always even Deadtime logic is bypassed
        * Two different edges can be captured due to two capture circuits are available on each input
        * Interrupt sources items are part of different structures, for example Compare value 2,3 in Channels => Channel A => PWM => Interrupt sources
*   Interrupt vector settings - Compare, Capture, Reload, Fault and Reload Error interrupts are part of different interrupt vectors (MCU specific)

### Fault Inputs

* Common for whole eFlexPWM module
* Used to prevent hardware damage
* Watch the DC overvoltage, undervoltage, and overcurrent
* There are 4 inputs per fault channel (usually there is just one channel)
* Possible to generate interrupt




