##Simple PWM Generation

###Control of 1 LED Light Intensity
Control the LED light intensity by changing the duty on channel B of the SM0.

**Start from default preset and continue with the following steps:**

   1) Edit **General configuration => Submodules**:  
  1. Just one submodule is needed **SM0**  
  
   2) Edit **SM0 => Main configuration**:  
  1.  Set the **Desired counter frequency/period** to *200* (**Counter resolution**: *200 ticks* - up to *65535 ticks*)
  2.  **Channel pair A and B mode** let *Independent* - to use just one channel (without half bridge connected, no specification of deadtime needed) 
  3.  **PWM alignment** set to *Unsigned edge-aligned* - counter starts counting from the 0  
  4.  **Reload logic setup** let *Immediate*, use **PWM_SetPwmLdok()** function to update working registers from buffer with new duty value  
  5.  **Set LDOK in initialization** ☑  
  6.  **Start counter in initialization** ☑  
   
   3) Edit **SM0 => Channels**:  
  1.  Select one **Channel** (except *X*), for example *B*.  
  2.  Change **Channel ID** to *LED_LIGHT* for better orientation of the channel setting in the called functions. 
  3.  Select *PWM* in **Function** item.  
  
  4) Edit **SM0 => Channels => PWM**:  
  1.  Setup the **Pulse width** to *50%* - half light intensity  
  
  5) Edit **Fault Channels => Faults:**  
  1.  All faults are always enabled - so set their **Active level** to *High* - default faults routing is to Logic 0 (**Pins tool**)
  
  6) Edit **Pins tool/Problems view:**  
  1.  Fulfill all routing warnings.  
  
  Note for Reload logic: 
  1. During runtime the intensity can be changed by function **PWM_UpdatePwmDutycycle()**. However, the value is written into the buffer only.  
  2. If the **Reload logic setup** item is set to the *Immediate* value, use **PWM_SetPwmLdok()** function to update the working registers from buffer with new duty value.  
  3. If the **Reload logic setup** item is set to the *other* values than *Immediate*, the working registers will be updated automatically when the selected action invokes.  
  
  Example of code for Kinetis KV4x, for other MCUs you can change the **Name** item to custom name *PWMA*:  
  7) Copy the following code into your "project".c main code:
---
    int main(void) {  
      static uint16_t delay = 0x0fffU;  
      uint32_t pwmVal = 0U;  
      uint16_t i;  
      
      /* Init board hardware. */  
      BOARD_InitBootPins();  
      BOARD_InitBootClocks();  
      BOARD_InitBootPeripherals();  
      /* Init FSL debug console. */  
      BOARD_InitDebugConsole();  
      
      while(1) {
        /* Delay for slow down duty change rate */
        for (i = 0U; i < delay; i++)  
          {  
              __ASM volatile("nop");  
          }  
          /* Increase duty by 25% */
          pwmVal = pwmVal + 25;  
  
          /* Reset the duty cycle percentage when it exceeds 100% */  
          if (pwmVal > 100)  
          {             
            pwmVal = 0;  
          }  
  
          /* Update duty cycle */  
          PWM_UpdatePwmDutycycle(PWMA_PERIPHERAL, PWMA_SM0, PWMA_SM0_LED_LIGHT, kPWM_EdgeAligned, pwmVal);  
  
          /* Set the load okay bit for all submodules to load registers from their buffer */  
          PWM_SetPwmLdok(PWMA_PERIPHERAL, kPWM_Control_Module_0, true);  
          
      }
      return 0;
    }
---
  8) Run the application.  
  9) Check PWM_B output by oscilloscope.  
