##Capture - Verification of the PWM Duty Width From Previous Use Case
Capturing the signal on SM0 channel X input connected (by external wire) with channel B PWM output and printing out the duty period value in ticks.

   0) Perform the steps from **Simple PWM generation use case** up to step 10) and continue with the following:
   1) Edit **SM0 => Channels**:  
  1.  Select another **Channel**, for example *X* - You can use this channel as Capture input only. 
  2.  Change **Channel ID** to *DUTY_CAPTURE* for better orientation of the channel setting in the called functions.  
  3.  Select *CAPTURE* in **Function** item.  
  
   2) Edit **SM0 => Channels => Capture**:  
  1.  Setup the **Circuits source** to *Raw input*  
  2.  Select capture edges:  
      - **Circuit 0 edge**: *Rising edge*  
      - **Circuit 1 edge**: *Falling edge*  
  3.  Select **Mode** to *Free running* - Without the need to arm Capture circuits again  
  4.  Set **FIFO watermark** to *0*  
  5. Select second **Capture X1** ☑ in **Interrupt sources** - to enable interrupt after both edges come  
  
   3) Find appropriate **SM0 => Enable capture interrupt vector** ☑ item  
   4) Edit **Capture interrupt vector settings**:  
  1.  **Enable custom handler name** ☑  
  2.  Set the *CAPTURED_DUTY_LED_LIGHT* as **Interrupt handler name**  
  
  Code example for Kinetis KV4x, for other MCUs you can change the **Name** item to custom name *PWMA*:  
  
  5) Copy following code into your "project".c variables and function declaration section:
---
      volatile uint32_t delta = 0U;

      /* PWMA_CAP_IRQn interrupt handler */
      void CAPTURED_DUTY_LED_LIGHT(void) {
        PWMA_PERIPHERAL->SM[PWMA_SM0].STS = (1 << 7);
        delta = PWMA_PERIPHERAL->SM[PWMA_SM0].CVAL1 - PWMA_PERIPHERAL->SM[PWMA_SM0].CVAL0;
      }
      
---

  6) Copy the following code into your "project".c main code:
      int main(void) {
        /* Code from Simple PWM generation use case - begin */
        static uint16_t delay = 0x0fffU;  
      uint32_t pwmVal = 0U;  
      uint16_t i;  
      
      /* Init board hardware. */  
      BOARD_InitBootPins();  
      BOARD_InitBootClocks();  
      BOARD_InitBootPeripherals();  
      /* Init FSL debug console. */  
      BOARD_InitDebugConsole();  
      
      while(1) {
        /* Delay for slow down duty change rate */
        for (i = 0U; i < delay; i++)  
          {  
              __ASM volatile("nop");  
          }  
          /* Increase duty by 25% */
          pwmVal = pwmVal + 25;  
  
          /* Reset the duty cycle percentage when it exceeds 100% */  
          if (pwmVal > 100)  
          {             
            pwmVal = 0;  
          }  
  
          /* Update duty cycle */  
          PWM_UpdatePwmDutycycle(PWMA_PERIPHERAL, PWMA_SM0, PWMA_SM0_LED_LIGHT, kPWM_EdgeAligned, pwmVal);  
  
          /* Set the load okay bit for all submodules to load registers from their buffer */  
          PWM_SetPwmLdok(PWMA_PERIPHERAL, kPWM_Control_Module_0, true);  
          /* Code from Simple PWM generation use case - end */
          /* PRINTF() have to be in the main(), otherwise the interrupt is invoked in newer counter cycle before finishing PRINTF() */
          PRINTF("%d\n", delta);
      }
      return 0;
    }
      
---
  **Note:** for editing **SM0 => Channels => Capture**:  
  1.  In the case of setup the **Circuits source** to *Edge counter*, user has to specify in the **Edge counter compare value** item number of all input edges (both rising and falling together) which generates the edge on input to the capture circuits.  
  2.  In the case of selection **Mode** to *One shot* - user has to arm Capture circuits again by wrinting appropriate **CAPTCTRLA[ARMA], CAPTCTRLB[ARMB] or CAPTCTRLX[ARMX]** bitfield (register\_name[bitfield\_name]).  
  
---
      /* Example of arming the capture on channel X as described above */
      PWMA_PERIPHERAL->SM[PWMA_SM0].CAPTCTRLX |= 0x1U; // ARMX bitfield for channel X in CAPTCTRLX register
      
---