#Interrupt configuration
Typical interrupt initialization provided by MCUXpresso Peripherals tool component consists of peripheral interrupt sources configuration and interrupt vector configuration:
- __Peripheral interrupt sources configuration__
    - Enables interrupt sources of the peripheral. 
    - Initializes peripheral registers using MCUXpresso SDK driver API.
- __Interrupt vector controller configuration__
    - Enables interrupt request in interrupt controller. 
    - Shows interrupt vector ID.
    - Optionally, configures interrupt request priority.
    - Allows to set interrupt handler name. 
    - Initializes interrupt vector controller registers using common MCUXpresso SDK API.

## Preprocessor macros
Following C preprocessor macros are generated to peripherals.h header file for each component:
- __&lt;COMPONENT_NAME&gt;_IRQN__ - Interrupt vector identifier. Contains processor-specific identifier (number) of the interrupt mapped from IRQn enumeration type defined by SDK.  
For example:

         #define PIT_1_IRQN PIT_IRQn

- __&lt;COMPONENT_NAME&gt;_IRQ_PRIORITY__ - Interrupt vector priority. Contains number (level) of the interrupt priority. This macro is generated only if priority initialization is enabled in the component.  
For example:

         #define PIT_1_IRQ_PRIORITY 3

- __&lt;interrupt_handler&gt;__ - Interrupt handler identifier. Contains name of the handler of the SDK interrupt vector table that is invoked by MCU interrupt controller. This macro can be used to implement a custom interrupt handler. By default, &lt;COMPONENT\_NAME&gt;\_IRQHANDLER is used as custom interrupt handler name.  
For example:

         #define PIT_1_IRQHANDLER PIT_IRQHandler

## Interrupt handlers
It's expected that interrupt handlers are implemented in the application code. The interrupt handler identifier macro generated by component into peripherals.h can be used to implement the handler.

For example, assume following interrupt handler identifier macro is generated in peripherals.h:

    #define PIT_1_IRQHANDLER PIT_IRQHandler

In such a case, you can put in the application code the following interrupt handler:  

    void PIT_1_IRQHANDLER(void) {
    
      /* Interrupt handler code, e.g. clear interrupt flags */
    
    }
